//***************************:
//
// mode 0 : 波長スペクトラ画像出力
//
//***************************
#include "lib/QE_R9880U_210.hh"
#include "lib/QE_R1250_03.hh"
#include "lib/Aerogel.hh"
#include "lib/Cherenkov.hh"
#include "lib/Kuraray_B3_300.hh"
#include "lib/Kuraray_Y11_300.hh"
#include "lib/PhotonEnergy.hh"

void mode1(){
    gROOT->LoadMacro("./include/ProcEvent.C");
    c1=new TCanvas("c1","",800,500);
    c1->Connect("ProcessedEvent(Int_t,Int_t,Int_t,TObject*)",
                0, 0, "ProcEvent(Int_t,Int_t,Int_t,TObject*)");
    c1->Divide(3,2);

    
    const int nEntries=80;
    const int n=nEntries;
    double x[n],y1[n],y2[n];
    char name[100];
    for(int i=0;i<nEntries;i++){
        x[i]=1240./photonEnergy[i];
        y1[i]=R9880U_210_QE[i];
        y2[i]=R1250_QE[i];
    }
    pmt1=new TGraph(n,x,y1);
    pmt2=new TGraph(n,x,y2);

    //PMT QE R9880U-210
    c1->cd(1)->SetGridx();
    c1->cd(1)->SetGridy();
    c1->cd(1)->SetLogy();
    pmt1->GetXaxis()->SetLimits(100,1000);
    pmt1->GetHistogram()->SetMaximum(1);
    pmt1->GetHistogram()->SetMinimum(1e-3);
    pmt1->SetMarkerStyle(20);
    pmt1->SetMarkerSize(0.5);
    pmt1->SetMarkerColor(1);
    pmt1->SetTitle("PMT QE R9880U-210");
    pmt1->Draw("ap");
    
    //PMT QE R1250-03
    c1->cd(2)->SetGridx();
    c1->cd(2)->SetGridy();
    c1->cd(2)->SetLogy();
    pmt2->GetXaxis()->SetLimits(100,800);
    pmt2->GetHistogram()->SetMaximum(1);
    pmt2->GetHistogram()->SetMinimum(1e-3);
    pmt2->SetMarkerStyle(20);
    pmt2->SetMarkerSize(0.5);
    pmt2->SetMarkerColor(1);
    pmt2->SetTitle("PMT QE R1250-03");
    pmt2->Draw("ap");
    
    //Y-11 spectra
    c1->cd(3)->SetGridx();
    c1->cd(3)->SetGridy();
    for(int i=0;i<nEntries;i++){
        x[i]=1240./photonEnergy[i];
        y1[i]=-absWLSF_Y11[i];
        y2[i]=emissionWLSF_Y11[i];
    }
    Y11abs=new TGraph(n,x,y1);
    Y11emi=new TGraph(n,x,y2);
    c1->SetLogy(0);
    Y11abs->SetTitle("Y-11(300)MJ");
    Y11abs->GetXaxis()->SetLimits(350,650);
    Y11abs->GetHistogram()->SetMaximum(1);
    Y11abs->GetHistogram()->SetMinimum(-1);
    Y11abs->SetMarkerStyle(20);
    Y11abs->SetLineColor(3);
    Y11abs->SetMarkerSize(0.5);
    Y11abs->SetMarkerColor(3);
    Y11abs->Draw("apl");
    Y11emi->SetMarkerStyle(20);
    Y11emi->SetLineColor(3);
    Y11emi->SetMarkerSize(0.5);
    Y11emi->SetMarkerColor(3);
    Y11emi->Draw("pl");
//    c1->Print(output);

    
    c1->cd(4)->SetGridx();
    c1->cd(4)->SetGridy();
    for(int i=0;i<nEntries;i++){
        x[i]=1240./photonEnergy[i];
        y1[i]=-absWLSF_B3[i];
        y2[i]=emissionWLSF_B3[i];
    }
    B3abs=new TGraph(n,x,y1);
    B3emi=new TGraph(n,x,y2);
    c1->SetLogy(0);
    B3abs->SetTitle("B-3(300)MJ");
    B3abs->GetXaxis()->SetLimits(250,600);
    B3abs->GetHistogram()->SetMaximum(1);
    B3abs->GetHistogram()->SetMinimum(-1);
    B3abs->SetMarkerStyle(20);
    B3abs->SetMarkerSize(0.5);
    B3abs->SetMarkerColor(4);
    B3abs->SetLineColor(4);
    B3abs->Draw("apl");
    B3emi->SetMarkerStyle(20);
    B3emi->SetMarkerSize(0.5);
    B3emi->SetMarkerColor(4);
    B3emi->SetLineColor(4);
    B3emi->Draw("pl");
//    c1->Print(output);

//    return;
    file=new TFile("rootfile/opt.root");
    c1->cd(5)->SetGridx();
    c1->cd(5)->SetGridy();
    double y3[nEntries],y4[nEntries];
    for(int i=0;i<nEntries;i++){
        x[i]=1240./photonEnergy[i];
        y2[i]=Cherenkov(photonEnergy[i]);
    }
    chere=new TGraph(n,x,y2);
    chere->GetXaxis()->SetLimits(200,800);
    chere->SetMarkerStyle(20);
    chere->SetMarkerSize(0.5);
    chere->SetMarkerColor(2);
    chere->GetHistogram()->SetMaximum(1);
    chere->SetLineColor(3);
    chere->SetMarkerColor(3);
    chere->SetTitle("Cherenkov photons from silica aerogel");
    chere->Draw("apl");
    
//    return;
    for(int i=0;i<6;i++){
        sprintf(name,"chgra%d",i);
        chgra=(TGraph*)file->Get(name);
        chgra->SetLineColor(2);
        chgra->SetMarkerColor(2);
        chgra->SetMarkerStyle(20);
        chgra->SetMarkerSize(0.3);
        chgra->Draw("pl");

        sprintf(name,"trgra%d",i);
        trgra=(TGraph*)file->Get(name);
        trgra->SetLineColor(1);
        trgra->SetMarkerColor(1);
        trgra->SetMarkerStyle(20);
        trgra->SetMarkerSize(0.3);
        trgra->Draw("pl");
    }
    file->Close();
    return;
    
}
        
