#include "lib/QE_R9880U_210.hh"
#include "lib/QE_R1250_03.hh"
#include "lib/Aerogel.hh"
#include "lib/Cherenkov.hh"
#include "lib/Kuraray_B3_300.hh"
#include "lib/Kuraray_Y11_300.hh"
#include "lib/PhotonEnergy.hh"

//********************************
//
// mode 2 : 直接PMT読み出しについての光電子数の厚さ依存性
//
//********************************

//
// 直接PMTでチェレンコフ光を観測した場合
// 宇宙線ミューオンが入射した時
//
void mode2(){
    graphDirectPMT=new TGraphAsymmErrors();
    double en_a,en_b;
    hist=new TH1F("hist","hist",100,200,800);
    hist2=new TH1F("hist2","hist2",100,200,800);
    file=new TFile("rootfile/opt.root");
    char name[100];
    double ent=0;
    double factor=100;
    double refrectionfactor=0.46;
    double airCherenkov=1.36;
    double integralvalue[7];
    double data[6]={4.9, 8.6, 10.8, 14.5, 17.8, 21.1};
    double datasigma[6]={0.2, 0.2, 0.3, 0.3, 0.4, 0.5};

    c1=new TCanvas("c1");
    
    TGraph*chgra[6];
    for(int i=0;i<6;i++){
        integralvalue[i]=ratio->GetBinContent(i);
        sprintf(name,"chgra%d",i);
        chgra[i]=(TGraph*)file->Get(name);}
    
    for(int kk=0;kk<6;kk++){
    //平均光子数の決定
    //これはエアロゲルのトランスミッタンスを考慮している。
    ent=2*3.14/137*(1.-1./1.05**2)*(1./200-1./800)*1e7*integralvalue[kk];
    
    for(int i=0;i<ent*factor;i++){
        
        //チェレンコフ光の発生
        do{
            en_a = gRandom->Uniform(1.38,6.20);
            for(int m=0;photonEnergy[m]<en_a;m++){}
            en_b = gRandom->Uniform(0.00,1.00);
        }while(en_b>chgra[kk]->GetY()[m]);//en_a...energy, en_b...spectrum
        hist->Fill(1240./en_a);

        //PMTでのQEフィルター
        en_b = gRandom->Uniform(0.00,1.00);
        if(en_b<=R1250_QE[m]){
            hist2->Fill(1240./en_a);
        }
        if(i%1000==0)cout<<"."<<flush;
    }cout<<endl<<flush;
        
    hist->Draw();
    hist2->SetLineColor(2);
    hist2->SetFillColor(2);
    hist2->SetFillStyle(3004);
    hist2->Draw("same");
    cout<<"Direct PMT observation for Cherenkov photons"<<endl;
    cout<<hist->GetEntries()<<" "
        <<hist2->GetEntries()<<" "
        <<hist2->GetEntries()/hist->GetEntries()<<endl;
    
    //実験結果と一致するようなフィットパラメータを代入
    //(1)空気チェレンコフ光  ariCherenkov
    //(2)反射板の反射率     reflectionfactor
    graphDirectPMT->SetPoint(kk,kk+1,
            hist2->GetEntries()/factor*refrectionfactor+airCherenkov);
    graphDirectPMT->SetPointError(kk,0,0,
                    sqrt(hist2->GetEntries())/factor*refrectionfactor,
                    sqrt(hist2->GetEntries())/factor*refrectionfactor);
    }

    //
    // simulation result
    //
    graphDirectPMT->SetMarkerSize(0.5);
    graphDirectPMT->SetMarkerColor(4);
    graphDirectPMT->SetLineColor(4);
    graphDirectPMT->SetMarkerStyle(24);
    graphDirectPMT->GetHistogram()->SetMaximum(24);
    graphDirectPMT->GetHistogram()->SetMinimum(0);
    graphDirectPMT->SetTitle("");
    graphDirectPMT->GetXaxis()->SetTitle("Aerogel Thickness (cm)");
    graphDirectPMT->GetYaxis()->SetTitle("Num. of Photoelectrons");
    graphDirectPMT->Draw("ap");

    
    //
    //data result same draw
    //
    graphData=new TGraphAsymmErrors();
    for(int i=0;i<6;i++){
        graphData->SetPoint(i,i+1,data[i]);
        graphData->SetPointError(i,0,0,datasigma[i],datasigma[i]);
    }
    graphData->SetMarkerStyle(20);
    graphData->SetMarkerSize(0.5);
    graphData->SetMarkerColor(1);
    graphData->Draw("p");
    
    return;
}

