#include "lib/QE_R9880U_210.hh"
#include "lib/QE_R1250_03.hh"
#include "lib/Aerogel.hh"
#include "lib/Cherenkov.hh"
#include "lib/Kuraray_B3_300.hh"
#include "lib/Kuraray_Y11_300.hh"
#include "lib/PhotonEnergy.hh"

//********************************
//
// mode 3 :WLSF経由についての光電子数
//         のエアロゲル厚さ依存性
//
//********************************

//
// WLSF経由でチェレンコフ光を観測した場合
// 宇宙線ミューオンが入射した時
//
void mode4(){
    graphDirectPMT=new TGraphAsymmErrors();
    hist=new TH1F("hist","hist",100,200,800);
    hist2=new TH1F("hist2","hist2",100,200,800);
    wls=new TH1F("wls","wls",100,200,800);
    wls2=new TH1F("wls2","wls2",100,200,800);//Y, B, B->Y (total)
    wls3=new TH1F("wls3","wls3",100,200,800);//Y
    wls4=new TH1F("wls4","wls4",100,200,800);//B
    wls5=new TH1F("wls5","wls5",100,200,800);//B->Y

    file=new TFile("rootfile/opt.root");
    
    int mm,ll;
    double en_a,en_b;
    char name[100];
    double ent=0;
    double factor=1000;
    double refrectionfactor=0.46;
    double airCherenkov=1.36;
    double integralvalue[7];
    double efftrap=0.108;//トラッピング効率
    double chisquare=0;
    double data[6]={0.29,0.55,0.72,0.70,0.74,0.82};
    double datasigma[6]={0.03,0.05,0.07,0.07,0.07,0.09};
    double airCherenkov=0.14761;//1.42;
    double effB3=0.435354;//pm0.00356//0.357;//再発光効率 B-3
    double effY11=effB3;//再発光効率 Y-11

    TGraph*chgra[6];
    for(int i=0;i<6;i++){
        integralvalue[i]=ratio->GetBinContent(i);
        sprintf(name,"chgra%d",i);
        chgra[i]=(TGraph*)file->Get(name);
    }

    int thick=1;
    cout<<"How long is aerogel thickness (1-6 cm)?"<<endl<<">>";
    cin>>thick;
    int kk=thick;

    cout<<"What number is Cherenkov photon emitted?"<<endl<<">>";
    cin>>ent;

    cout<<"What is factor?"<<endl<<">>";
    cin>>factor;


    for(int i=0;i<ent*factor;i++){
        //(1)エアロゲルからチェレンコフ光放射
        do{
            en_a = gRandom->Uniform(1.38,6.20);
            for(int m=0;photonEnergy[m]<en_a;m++){}
            en_b = gRandom->Uniform(0.00,1.00);
        }while(en_b>chgra[kk]->GetY()[m]);//en_a...energy, en_b...spectrum
        hist->Fill(1240./en_a);
        wls->Fill(1240./en_a);
        
        //(2)B-3の吸収率
        en_b = gRandom->Uniform(0.00,1.00);
        if(en_b>effB3) continue;//吸収されなければ下層へ
        
        //(2.1)B-3での吸収強度
        en_b = gRandom->Uniform(0.00,1.00);
        if(en_b<absWLSF_B3[m]){
                
            //(2.2)B-3 波長変換
            do{ en_a = gRandom->Uniform(1.38,6.20);
                for(int m=0;photonEnergy[m]<en_a;m++){}
                en_b = gRandom->Uniform(0.00,1.00);
            }while(en_b>emissionWLSF_B3[m]);
                
            //(2.3)伝搬効率
            en_b = gRandom->Uniform(0.00,1.00);
            if(en_b<=efftrap){
                    
                //(2.3.1)PMT QE
                en_b = gRandom->Uniform(0.00,1.00);
                if(en_b<R9880U_210_QE[m]){
                        wls2->Fill(1240./en_a);
                        wls3->Fill(1240./en_a);
                    }
                }
                
            //(2.4)伝搬されず漏れたらY-11にいく
            else{
                //(2.4.1)B-3からY-11への立体角
                en_b = gRandom->Uniform(0.00,1.00);
                if(en_b>0.5) continue;
                
                //(2.4.2)Y-11吸収率
                en_b = gRandom->Uniform(0.00,1.00);
                if(en_b>effY11) continue;//再発光効率
                
                //(2.4.3)Y-11吸収強度
                en_b = gRandom->Uniform(0.00,1.00);
                if(en_b<absWLSF_Y11[m]){
                    
                    //(2.4.4) Y-11波長変換
                    do{en_a = gRandom->Uniform(1.38,6.20);
                        for(int m=0;photonEnergy[m]<en_a;m++){}
                        en_b = gRandom->Uniform(0.00,1.00);
                    }while(en_b>emissionWLSF_Y11[m]);
                    
                    //(2.4.5)伝搬効率
                    en_b = gRandom->Uniform(0.00,1.00);
                    if(en_b<=efftrap){
                        
                        //(2.4.6)PMT QE
                        en_b = gRandom->Uniform(0.00,1.00);
                        if(en_b<R9880U_210_QE[m]){
                            wls2->Fill(1240./en_a);
                            wls5->Fill(1240./en_a);
                        }
                    }
                }
            }
        }
            
        else{//(3) B-3を透過したチェレンコフはY-11へ入射
            
            //(3.1) Y-11吸収率
            en_b = gRandom->Uniform(0.00,1.00);
            if(en_b>effY11) continue;

            //(3.2)Y-11吸収強度
            en_b = gRandom->Uniform(0.00,1.00);
            if(en_b<absWLSF_Y11[m]){
                
                //(3.3)Y-11波長変換
                do{ en_a = gRandom->Uniform(1.38,6.20);
                    for(int m=0;photonEnergy[m]<en_a;m++){}
                    en_b = gRandom->Uniform(0.00,1.00);
                }while(en_b>emissionWLSF_Y11[m]);
                
                //(3.4)伝搬効率
                en_b = gRandom->Uniform(0.00,1.00);
                if(en_b<=efftrap){
                    
                    //(3.5) PMT QE
                    en_b = gRandom->Uniform(0.00,1.00);
                    if(en_b<R9880U_210_QE[m]){
                        wls2->Fill(1240./en_a);
                        wls4->Fill(1240./en_a);
                    }
                }
            }
        }
        if(i%1000==0)cout<<"."<<flush;
    }
    cout<<endl<<flush;
    hist2->SetLineColor(2);
    hist2->SetFillColor(2);
    hist2->SetFillStyle(3004);

//    c1=new TCanvas("c1");

    cout<<"Num. Chere. photons from aerogel:"<<wls->Integral()/factor<<" photons"<<endl;
    cout<<"Num. Chere. p.e. via WLSF + PMT: "<<wls2->Integral()/factor<<" p.e."<<endl;
    cout<<"Num. Chere. p.e. via B3:         "<<wls3->Integral()/factor<<" p.e."<<endl;
    cout<<"Num. Chere. p.e. via Y11:        "<<wls4->Integral()/factor<<" p.e."<<endl;
    cout<<"Num. Chere. p.e. via B3->Y11:    "<<wls5->Integral()/factor<<" p.e."<<endl;

    c1=new TCanvas("c1","",700,350);
    c1->Divide(2,1);
    c1->cd(1)->SetLogy();
    wls->SetLineColor(1);
    wls->SetFillColor(1);
    wls->SetFillStyle(3003);
    wls->GetYaxis()->SetRangeUser(1,wls->GetMaximum()*1.2);
    wls->Draw();
    wls2->SetLineColor(2);
    wls2->SetFillColor(2);
    wls2->SetFillStyle(3004);
    wls2->Draw("same");

    c1->cd(2)->SetLogy();
    wls2->Draw();
    wls3->SetLineColor(4);
    wls3->Draw("same");
    wls4->SetLineColor(3);
    wls4->Draw("same");
    wls5->SetLineColor(6);
    wls5->Draw("same");

    
    return;
}

